@@ -1,4 +1,4 @@
-from .Rrandom import Rinit, Random
+from .Rrandom import Random
 from .Rmath import Math
 from .Rrequests import Request
 from .Rsugaku import Sugaku
